model MichaelisMenten "Comparison between a rection under Michaelis-Menten reaction kinetics and a reaction using mass-action equations."
  extends BioChem.Compartments.ConstantCompartment(V.fixed = true);
  BioChem.Reactions.MichaelisMenten.Uui uui1(vF = kCat * Ec0, KmS = (kOff + kCat) / kOn) "The Michaelis-Menten reaction." annotation(Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance E "The enzyme provide a lower energy reaction path for the reaction by stabilizing the transition state, greatly increasing the reaction rate." annotation(Placement(visible = true, transformation(origin = {-80, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance S1(c.start = Sc0, c.fixed = true) "Substrate, which is defined as a reactant that is consumed in a enzymatic (or catalytic) reaction." annotation(Placement(visible = true, transformation(origin = {-80, -0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance S2(c.start = Sc0, c.fixed = true) "Substrate, which is defined as a reactant that is consumed in a enzymatic (or catalytic) reaction." annotation(Placement(visible = true, transformation(origin = {-80, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Reversible.BiUni.Bur bur(k1 = kOn, k2 = kOff) "The reversible, first reaction in the short reaction chain from substrate to product." annotation(Placement(visible = true, transformation(origin = {-40, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance ES(c.start = 0.05) "The enzyme-substrate complex. The enzyme reversibly binds the substrate, stabilizing its transition state." annotation(Placement(visible = true, transformation(origin = {0, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance P1(c.start = Pc0, c.fixed = true) "The resulting substance of the reaction." annotation(Placement(visible = true, transformation(origin = {80, -0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance P2(c.start = Pc0, c.fixed = true) "The resulting substance of the reaction." annotation(Placement(visible = true, transformation(origin = {80, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  parameter Real kOn = 2 "Association constant for enzyme-substrate binding reaction";
  parameter Real kOff = 4 "Disassociation constant for enzyme-substrate binding reaction";
  parameter Real kCat = 0.5 "Reaction rate constant for enzyme reaction";
  parameter BioChem.Units.Concentration Sc0 = 0.01 "Initial concentration of substrate" annotation(Dialog(group = "Initialization"));
  parameter BioChem.Units.Concentration Pc0 = 0 "Initial concentration of product" annotation(Dialog(group = "Initialization"));
  parameter BioChem.Units.Concentration Ec0 = 0.05 "Initial concentration of enzymes" annotation(Dialog(group = "Initialization"));
  BioChem.Reactions.MassAction.Reversible.UniBi.Ubr ubr(k1 = kCat, k2 = 0.00001) "The last reaction of the short chain from substrate to product. The forward rate is controlled by the kCat constant." annotation(Placement(visible = true, transformation(origin = {33.496, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  encapsulated type Init = enumeration(NoInit "No initialization (start values are used as guess values with fixed=false)", SteadyState "Steady state initialization", Zero "Initialization with 0 enzyme complex concentration") "Enumeration defining initialization of the enzyme complex" annotation(Evaluate = true, Documentation(info = "<html>
     <p>The following initialization alternatives are available:</p>
     <dl>
       <dt><code><strong>NoInit</strong></code></dt>
         <dd>No initialization (start values are used as guess values with <code>fixed=false</code>)</dd>
       <dt><code><strong>SteadyState</strong></code></dt>
         <dd>Steady state initialization (derivatives of states are zero)</dd>
       <dt><code><strong>InitialState</strong></code></dt>
         <dd>Initialization with initial states</dd>
       <dt><code><strong>InitialOutput</strong></code></dt>
         <dd>Initialization with initial outputs (and steady state of the states if possible)</dd>
     </dl>
   </html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {56, 56, 56}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Text(visible = true, textColor = {0, 114, 195}, extent = {{-90, -50}, {90, 50}}, textString = "1..n")}));
  parameter Init enzymeInitialization = MichaelisMenten.Init.Zero "Initialization options for the enzyme reaction, see documentation" annotation(Dialog(group = "Initialization"));
initial equation
  E.c + ES.c = Ec0;
  if enzymeInitialization == Init.SteadyState then
    ubr.rr = bur.rr;
  elseif enzymeInitialization == Init.Zero then
    ES.c = 0;
  end if;
equation
  connect(E.n1, bur.s1) annotation(Line(visible = true, origin = {-70.417, 30}, points = {{-9.583, 10}, {-9.583, -5}, {19.167, -5}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(S1.n1, bur.s2) annotation(Line(visible = true, origin = {-70.417, 10}, points = {{-9.583, -10}, {-9.583, 5}, {19.167, 5}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(bur.p1, ES.n1) annotation(Line(visible = true, origin = {-14.375, 20}, points = {{-14.375, 0}, {0, 0}, {0, 0}, {14.375, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(S2.n1, uui1.s1) annotation(Line(visible = true, origin = {-45.625, -20}, points = {{-34.375, 0}, {0, 0}, {0, 0}, {34.375, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(uui1.p1, P2.n1) annotation(Line(visible = true, origin = {45.625, -20}, points = {{-34.375, 0}, {0, 0}, {0, 0}, {34.375, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ES.n1, ubr.s1) annotation(Line(visible = true, origin = {11.123, 20}, points = {{-11.123, 0}, {0, 0}, {0, 0}, {11.123, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ubr.p2, P1.n1) annotation(Line(visible = true, origin = {64.686, 7.5}, points = {{-19.94, 7.5}, {2.314, 7.5}, {2.314, -7.5}, {15.314, -7.5}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ubr.p1, E.n1) annotation(Line(visible = true, origin = {23.687, 32.5}, points = {{21.059, -7.5}, {56.313, -7.5}, {56.313, 7.5}, {16.313, 7.5}, {-103.687, 7.5}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  annotation(uses(Modelica(version = "4.0.0"), BioChem(version = "2.0")), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {119, 163, 37}, fillColor = {242, 224, 152}, fillPattern = FillPattern.Solid, lineThickness = 4, extent = {{-110, -110}, {110, 110}}, radius = 20), Text(visible = mainCompartment, origin = {1.438, -5}, extent = {{-111.438, -45}, {108.562, 45}}, textString = "main", fontName = "Arial"), Rectangle(visible = true, origin = {3.188, 0}, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-113.188, -113.188}, {113.188, 113.188}}, radius = 25), Text(visible = true, origin = {17.682, 26.428}, textColor = {255, 255, 255}, extent = {{-124.457, -86.428}, {95.173, 35.589}}, textString = "Ex", fontName = "Arial")}), experiment(StopTime = 120, __Wolfram_SynchronizeWithRealTime = false), Documentation(info = "<html>

<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/biochem/\">BioChem</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/BioChem.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px; \">The free BioChem library is an extendable, general purpose Modelica library for modeling, simulation and visualization of biological and biochemical systems. The library is designed to be used together with Wolfram System Modeler, which enables several extra features such as Systems Biology Markup Language (SBML) import and export. BioChem can, for instance, be used for selecting drug targets with PK/PD modeling or searching for novel drug targets with mechanistic modeling of the reactions in a cell or organism.</li>

	</ul>

</div>
    <h4>Model</h4>

    <p>
This model studies the Michaelis&ndash;Menten kinetics and compares it to a standard, enzyme-catalyzed mass action reaction.
</p><p>
Michaelis&ndash;Menten kinetics is one of the most important models for enzyme-substrate interactions. It is used to study the kinetics in a wide array of biological functions, such as the immune response.
</p><p>
While a mass action model of an enzyme-substrate interaction would go through a intermediate step with an enzyme-substrate complex, Michealis&ndash;Menten kinetics assumes that this complex rapidly enters quasi steady state and can be approximated. This eliminates the need to measure the formation rate of this complex, which is infeasible in practice.
</p>

   
  
    <p>
The example model consists of two separate reaction models. The upper, larger model follows mass action kinetics, having an enzyme that binds to the substrate, creating an enzyme-substrate complex before transforming the substrate into product. The smaller model follows Michaelis&ndash;Menten kinetics, with its reaction rate formula representing the enzyme reaction seen in the mass action model.
</p><a id=\"headerTag_Simulation\">&nbsp;</a>
    <h4>Simulation</h4>
    <p>
Simulating the model will give the possibility to see how well the Michaelis&ndash;Menten model agrees with the mass action one (which is more biologically correct).
</p>

<p>Simulate the model by clicking the Simulate button: <img src=\"modelica://MichaelisMenten/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<p>
If the models do not seem to agree, try to increase the  <span>kCat</span> constant, which represents the product formation from the enzyme-substrate complex. The higher the <span>kCat</span>, the better the models should agree. You can also change other parameters and initial conditions. This can be done in the  <span>Parameters</span> tab. Change the corresponding initial concentration and then click the <span>Simulate</span> button <img src=\"modelica://MichaelisMenten/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /> again.
</p>

<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>
<p>For the full example, open the accompanying notebook <a href=\"MichaelisMenten.nb\">MichaelisMenten.nb</a>.</p>

</html>", figures = {Figure(title = "Concentrations", identifier = "117c6", preferred = true, plots = {Plot(curves = {Curve(y = S1.c, legend = "Substrate (Mass Action)"), Curve(y = S2.c, legend = "Substrate (Michaelis-Menten)")}), Plot(curves = {Curve(y = P1.c, legend = "Product (Mass Action)"), Curve(y = P2.c, legend = "Product (Michaelis-Menten)")})}), Figure(title = "Product concentrations", identifier = "d2283", plots = {Plot(curves = {Curve(y = P1.c, legend = "Product (Mass Action)"), Curve(y = P2.c, legend = "Product (Michaelis-Menten)")})}), Figure(title = "Substrate concentrations", identifier = "c0c31", plots = {Plot(curves = {Curve(y = S1.c, legend = "Substrate (Mass Action)"), Curve(y = S2.c, legend = "Substrate (Michaelis-Menten)")})}), Figure(title = "Enzyme complex concentrations", identifier = "7f578", plots = {Plot(curves = {Curve(y = E.c, legend = "Enzyme"), Curve(y = ES.c, legend = "Enzyme Complex")})}), Figure(title = "Reaction rates", identifier = "65518", plots = {Plot(curves = {Curve(y = der(S1.c), legend = "Substrate Depletion (Mass Action)"), Curve(y = der(S2.c), legend = "Substrate Depletion (Michaelis-Menten)")}), Plot(curves = {Curve(y = der(P1.c), legend = "Product Formation (Mass Action)"), Curve(y = der(P2.c), legend = "Product Formation (Michaelis-Menten)")}), Plot(curves = {Curve(y = der(ES.c), legend = "Complex Formation (Mass Action)")})}), Figure(title = "Product formation rates", identifier = "5f6da", plots = {Plot(curves = {Curve(y = der(P1.c), legend = "Product Formation (Mass Action)"), Curve(y = der(P2.c), legend = "Product Formation (Michaelis-Menten)")})}), Figure(title = "Substrate depletion rates", identifier = "0f49b", plots = {Plot(curves = {Curve(y = der(S1.c), legend = "Substrate Depletion (Mass Action)"), Curve(y = der(S2.c), legend = "Substrate Depletion (Michaelis-Menten)")})}), Figure(title = "Complex formation rate", identifier = "e9208", plots = {Plot(curves = {Curve(y = der(ES.c), legend = "Complex Formation")})}), Figure(title = "Substrate concentration vs formation rate", identifier = "c9de2", plots = {Plot(curves = {Curve(x = S1.c, y = der(P1.c), legend = "Product Formation vs. Substrate Concentration (Mass Action)"), Curve(x = S2.c, y = der(P2.c), legend = "Product Formation vs. Substrate Concentration (Michaelis-Menten)")})})}), __Wolfram(ControlPanels(Panel(identifier = "charming-brahmagupta", title = "Model parameters", elements = {InputField(variable = Ec0, label = "Initial concentration of enzymes"), InputField(variable = Pc0, label = "Initial concentration of product"), InputField(variable = Sc0, label = "Initial concentration of substrate"), InputField(variable = V, label = "Compartment volume (constant)"), InputField(variable = kCat, label = "Reaction rate constant for enzyme reaction"), InputField(variable = kOff, label = "Disassociation constant for enzyme-substrate binding reaction"), InputField(variable = kOn, label = "Association constant for enzyme-substrate binding reaction")}))), Diagram(coordinateSystem(extent = {{-100, -40}, {100, 60}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end MichaelisMenten;
